@@ -1,7 +1,7 @@
 """Builders
 Module containing builders, which help build inputs for Instruction parameters
 
-    :copyright: 2020 by The Autoprotocol Development Team, see AUTHORS
+    :copyright: 2021 by The Autoprotocol Development Team, see AUTHORS
         for more details.
     :license: BSD, see LICENSE for more details
 
@@ -25,15 +25,14 @@ Instruction
 """
 
 from collections import defaultdict
-from numbers import Number
-
 from collections.abc import Iterable  # pylint: disable=no-name-in-module
 from functools import reduce
+from numbers import Number
 
 from .constants import SBS_FORMAT_SHAPES
-from .container import WellGroup, Well, Container
+from .container import Container, Well, WellGroup
 from .unit import Unit
-from .util import parse_unit, is_valid_well
+from .util import is_valid_well, parse_unit
 
 
 class InstructionBuilders(object):  # pylint: disable=too-few-public-methods
@@ -2466,18 +2465,18 @@ class FlowCytometryBuilders(InstructionBuilders):
 
     def __init__(self):
         super(FlowCytometryBuilders, self).__init__()
-        self.excitation = None
+        self.gating_modes = ("FSC", "SSC")
 
-    def laser(self, excitation, channels, power=None, area_scaling_factor=None):
+    def laser(self, channels, excitation=None, power=None, area_scaling_factor=None):
         """
         Generates a dict of laser parameters.
 
         Parameters
         ----------
-        excitation : Unit or str
-            Excitation wavelength.
         channels : list(dict)
             See :meth:`FlowCytometryBuilders.channel`.
+        excitation : Unit or str, optional
+            Excitation wavelength.
         power : Unit or str, optional
             Laser power.
         area_scaling_factor : Number, optional
@@ -2491,6 +2490,8 @@ class FlowCytometryBuilders(InstructionBuilders):
             If `channels` is not a list of dict.
         TypeError
             If `area_scaling_factor` is not a number.
+        ValueError
+            If a gating channel (e.g. SSC) is specified and excitation is also specified.
 
         Returns
         -------
@@ -2514,11 +2515,19 @@ class FlowCytometryBuilders(InstructionBuilders):
         if excitation is not None:
             excitation = parse_unit(excitation, "nanometers")
 
-        self.excitation = excitation
         channels = [self.channel(**_) for _ in channels]
 
+        # Gating modes do not allow specification of excitation parameter
+        channel_names = set(
+            [chn["emission_filter"]["channel_name"] for chn in channels]
+        )
+        if channel_names.intersection(self.gating_modes) and excitation is not None:
+            raise ValueError(
+                f"Cannot specify excitation if channel_name is one of {self.gating_modes}"
+            )
+
         return {
-            "excitation": self.excitation,
+            "excitation": excitation,
             "power": power,
             "area_scaling_factor": area_scaling_factor,
             "channels": channels,
@@ -2608,12 +2617,12 @@ class FlowCytometryBuilders(InstructionBuilders):
         dict
             A dict of emission_filter params.
         """
-        gating_modes = ("FSC", "SSC")
-        if channel_name in gating_modes and (shortpass or longpass or self.excitation):
+
+        if channel_name in self.gating_modes and (shortpass or longpass):
             raise ValueError(
-                f"Cannot specify shortpass/longpass/excitation "
-                f"parameters if channel_name is one "
-                f"{gating_modes}"
+                f"Cannot specify shortpass/longpass "
+                f"parameters if channel_name is one of "
+                f"{self.gating_modes}"
             )
 
         if shortpass is not None:
