@@ -1,7 +1,7 @@
 """
 Container, Well, WellGroup objects and associated functions
 
-    :copyright: 2020 by The Autoprotocol Development Team, see AUTHORS
+    :copyright: 2021 by The Autoprotocol Development Team, see AUTHORS
         for more details.
     :license: BSD, see LICENSE for more details
 
@@ -13,6 +13,7 @@ import warnings
 from .constants import SBS_FORMAT_SHAPES
 from .unit import Unit
 
+
 SEAL_TYPES = ["ultra-clear", "foil", "breathable"]
 COVER_TYPES = ["standard", "low_evaporation", "universal"]
 
@@ -423,7 +424,7 @@ class WellGroup(object):
                 [
                     w
                     for w in self.wells
-                    if prop in w.properties and w.properties[prop] is val
+                    if prop in w.properties and w.properties[prop] == val
                 ]
             )
         else:
