@@ -1,16 +1,16 @@
 """
 Container-type object and associated functions
 
-    :copyright: 2020 by The Autoprotocol Development Team, see AUTHORS
+    :copyright: 2021 by The Autoprotocol Development Team, see AUTHORS
         for more details.
     :license: BSD, see LICENSE for more details
 
 """
 
-from collections import namedtuple
-
 import re
 
+from collections import namedtuple
+
 from .container import Well
 from .unit import Unit
 
@@ -1166,6 +1166,72 @@ FLAT384WHITECLEAR = ContainerType(
     cat_no="3763",
 )
 
+#:
+FALCON96UBOTTOM = ContainerType(
+    name="Falcon 96-Well, Cell Culture-Treated, U-Shaped-Bottom Microplate",
+    shortname="96-ubottom-clear-tc",
+    is_tube=False,
+    well_coating=None,
+    sterile=False,
+    well_count=96,
+    col_count=12,
+    well_depth_mm=Unit(10.5, "millimeter"),
+    well_volume_ul=Unit(320, "microliter"),
+    dead_volume_ul=Unit(50, "microliter"),
+    safe_min_volume_ul=Unit(50, "microliter"),
+    capabilities=[
+        "pipette",
+        "spin",
+        "incubate",
+        "cover",
+        "stamp",
+        "dispense-destination",
+        "provision",
+        "uncover",
+        "seal",
+        "unseal",
+    ],
+    cover_types=["low_evaporation", "standard", "universal"],
+    seal_types=["ultra-clear", "foil"],
+    vendor="Corning",
+    cat_no="353077",
+)
+
+#:
+FLAT96DELTA = ContainerType(
+    name="Nunc MicroWell 96-Well, Nunclon Delta-Treated, Flat-Bottom Microplate",
+    shortname="96-flat-white-dc",
+    is_tube=False,
+    well_coating=None,
+    sterile=True,
+    well_count=96,
+    col_count=12,
+    well_depth_mm=Unit(11.2, "millimeter"),
+    well_volume_ul=Unit(320, "microliter"),
+    dead_volume_ul=Unit(50, "microliter"),
+    safe_min_volume_ul=Unit(50, "microliter"),
+    capabilities=[
+        "pipette",
+        "spin",
+        "incubate",
+        "cover",
+        "stamp",
+        "dispense-destination",
+        "provision",
+        "uncover",
+        "seal",
+        "unseal",
+        "liquid_handle",
+        "absorbance",
+        "fluorescence",
+        "luminescence",
+    ],
+    cover_types=["low_evaporation", "standard", "universal"],
+    seal_types=["ultra-clear", "foil"],
+    vendor="ThermoFisher",
+    cat_no="136101",
+)
+
 _CONTAINER_TYPES = {
     "384-flat": FLAT384,
     "384-pcr": PCR384,
@@ -1196,4 +1262,6 @@ _CONTAINER_TYPES = {
     "384-echo-ldv-plus": ECHO384LDVPLUS,
     "384-flat-white-clear": FLAT384WHITECLEAR,
     "96-well-v-bottom": V96CC,
+    "96-ubottom-clear-tc": FALCON96UBOTTOM,
+    "96-flat-white-dc": FLAT96DELTA,
 }
