@@ -1,22 +1,23 @@
 """
 Module containing the harness module which helps with Manifest interpretation
 
-    :copyright: 2020 by The Autoprotocol Development Team, see AUTHORS
+    :copyright: 2021 by The Autoprotocol Development Team, see AUTHORS
         for more details.
     :license: BSD, see LICENSE for more details
 
 """
 
-import json
-
 import argparse
 import io
+import json
 
 from . import UserError
+from .compound import Compound, CompoundError
 from .container import WellGroup
 from .protocol import Protocol
 from .unit import Unit, UnitError
 
+
 _DYE_TEST_RS = {"dye4000": "rs18qmhr7t9jwq", "water": "rs17gmh5wafm5p"}
 
 
@@ -200,6 +201,20 @@ def convert_param(protocol, val, type_desc):
                 f"The value supplied to input '{label}' (type aliquot++) is "
                 f"improperly formatted."
             )
+    elif type in "compound":
+        try:
+            return Compound(val)
+        except CompoundError as e:
+            raise RuntimeError(f"Invalid Compound; Details: {e.value}")
+    elif type == "compound+":
+        try:
+            return [convert_param(protocol, cont, "compound") for cont in val]
+        except:
+            label = type_desc.get("label") or "[unknown]"
+            raise RuntimeError(
+                f"The value supplied to input '{label}' (type compound+) is "
+                f"improperly formatted."
+            )
     elif type == "container":
 
         try:
